==> openGion_core_5.8.8.0.zip: ge/db/oracle/sql/install/02_INDEX/GE39C.sql <==
/****************************************************************************/
/* GE39 ( ﾌｧｲﾙ管理ﾃｰﾌﾞﾙ )                                                   */
/* Created : 2014/12/16 09:05:42                                            */
/****************************************************************************/

ALTER TABLE GE39 DROP CONSTRAINT GE39_UQ;
ALTER TABLE GE39 ADD CONSTRAINT GE39_UQ PRIMARY KEY ( UNIQ )
USING INDEX TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

ALTER TABLE GE39 DROP CONSTRAINT GE39_LUQ;
ALTER TABLE GE39 ADD CONSTRAINT GE39_LUQ UNIQUE( UNIQ_ID )
USING INDEX TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

DROP INDEX GE39_SA;
CREATE INDEX GE39_SA ON GE39( SEQNO )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

DROP INDEX GE39_SB;
CREATE INDEX GE39_SB ON GE39( SYSTEM_ID,SYFILE )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

DROP INDEX GE39_SC;
CREATE INDEX GE39_SC ON GE39( REF_KEY )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

DROP INDEX GE39_SD;
CREATE INDEX GE39_SD ON GE39( SUFFIX )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

DROP INDEX GE39_SE;
CREATE INDEX GE39_SE ON GE39( SAVE_FOLDER )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

DROP INDEX GE39_SF;
CREATE INDEX GE39_SF ON GE39( FILE_URL )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

DROP INDEX GE39_SG;
CREATE INDEX GE39_SG ON GE39( DYFILESET )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

DROP INDEX GE39_SH;
CREATE INDEX GE39_SH ON GE39( USRTOROKU )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

==> openGion_core_5.9.2.0.zip: ge/db/oracle/sql/install/02_INDEX/GE39C.sql <==
/****************************************************************************/
/* GE39 ( ﾌｧｲﾙ管理ﾃｰﾌﾞﾙ )                                                   */
/* Created : 2015/10/28 15:14:26                                            */
/****************************************************************************/

ALTER TABLE GE39 DROP CONSTRAINT GE39_UQ;
ALTER TABLE GE39 ADD CONSTRAINT GE39_UQ PRIMARY KEY ( UNIQ )
USING INDEX TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K);

ALTER TABLE GE39 DROP CONSTRAINT GE39_LUQ;
ALTER TABLE GE39 ADD CONSTRAINT GE39_LUQ UNIQUE( UNIQ_ID )
USING INDEX TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K);

DROP INDEX GE39_SA;
CREATE INDEX GE39_SA ON GE39( SEQNO )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K);

DROP INDEX GE39_SB;
CREATE INDEX GE39_SB ON GE39( SYSTEM_ID,SYFILE )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K);

DROP INDEX GE39_SC;
CREATE INDEX GE39_SC ON GE39( REF_KEY )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K);

DROP INDEX GE39_SD;
CREATE INDEX GE39_SD ON GE39( SUFFIX )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K);

DROP INDEX GE39_SE;
CREATE INDEX GE39_SE ON GE39( SAVE_FOLDER )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K);

DROP INDEX GE39_SF;
CREATE INDEX GE39_SF ON GE39( FILE_URL )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K);

DROP INDEX GE39_SG;
CREATE INDEX GE39_SG ON GE39( DYFILESET )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K);

DROP INDEX GE39_SH;
CREATE INDEX GE39_SH ON GE39( USRTOROKU )
TABLESPACE GEIDX01
STORAGE( INITIAL 16K NEXT 16K);
